@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2020 Accurics, Inc.
+    Copyright (C) 2022 Tenable, Inc.
 
 	Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -18,13 +18,10 @@ package httpserver
 
 // APIHandler struct for http api server
 type APIHandler struct {
-	test       bool
-	configFile string
+	test bool
 }
 
 // NewAPIHandler returns a new APIHandler{}
-func NewAPIHandler(configFile string) *APIHandler {
-	return &APIHandler{
-		configFile: configFile,
-	}
+func NewAPIHandler() *APIHandler {
+	return &APIHandler{}
 }
