@@ -27,7 +27,7 @@ import (
 // resources present in rootDir and descendant modules
 func (*TfV12) LoadIacDir(absRootDir string, options map[string]interface{}) (allResourcesConfig output.AllResourceConfigs, err error) {
 	zap.S().Warn("There may be a few breaking changes while working with terraform v0.12 files. For further information, refer to https://github.com/tenable/terrascan/releases/v1.3.0")
-	return commons.NewTerraformDirectoryLoader(absRootDir, options).LoadIacDir()
+	return commons.NewTerraformDirectoryLoader(absRootDir, version, options).LoadIacDir()
 }
 
 // Name returns name of the provider
