@@ -21,7 +21,7 @@ import (
 	"crypto/x509"
 	"encoding/json"
 	"fmt"
-	"io/ioutil"
+	"io"
 	"net/http"
 	"os"
 	"strings"
@@ -40,7 +40,7 @@ const (
 	registryDomain           = "HARBOR_REGISTRY_DOMAIN"
 )
 
-//ServerCaller interface with client methods
+// ServerCaller interface with client methods
 type ServerCaller interface {
 	Do(req *http.Request) (*http.Response, error)
 }
@@ -52,10 +52,10 @@ type harborScanner interface {
 	getClient() *http.Client
 }
 
-//scanner implementor for harborScanner interface
+// scanner implementor for harborScanner interface
 type hscanner struct{}
 
-//Harbor  Harbor container registry
+// Harbor  Harbor container registry
 type Harbor struct {
 	scanner harborScanner
 }
@@ -66,7 +66,7 @@ func init() {
 	})
 }
 
-//prepareRequest prepares http request
+// prepareRequest prepares http request
 func (hscanner) prepareRequest(serverURL string) (*http.Request, error) {
 	username := os.Getenv(registryUsername)
 	password := os.Getenv(registryPassword)
@@ -92,7 +92,7 @@ func (hscanner) prepareRequest(serverURL string) (*http.Request, error) {
 	return req, nil
 }
 
-//getClient prepares http client
+// getClient prepares http client
 func (hscanner) getClient() *http.Client {
 	tlsConfig := &tls.Config{}
 
@@ -105,7 +105,7 @@ func (hscanner) getClient() *http.Client {
 
 	cert := os.Getenv(certificate)
 	if cert != "" {
-		caCert, err := ioutil.ReadFile(cert)
+		caCert, err := os.ReadFile(cert)
 		if err != nil {
 			errorMsg := fmt.Errorf("client certificate not found")
 			zap.S().Error(errorMsg)
@@ -123,7 +123,7 @@ func (hscanner) getClient() *http.Client {
 	}
 }
 
-//sendRequest sends request to harbor
+// sendRequest sends request to harbor
 func (hscanner) sendRequest(caller ServerCaller, req *http.Request) ([]byte, error) {
 	res, err := caller.Do(req)
 	if err != nil {
@@ -134,7 +134,7 @@ func (hscanner) sendRequest(caller ServerCaller, req *http.Request) ([]byte, err
 
 	defer res.Body.Close()
 
-	body, err := ioutil.ReadAll(res.Body)
+	body, err := io.ReadAll(res.Body)
 	if err != nil {
 		errorMsg := fmt.Errorf("error reading response from harbor: %v", err)
 		zap.S().Error(errorMsg)
@@ -149,7 +149,7 @@ func (hscanner) sendRequest(caller ServerCaller, req *http.Request) ([]byte, err
 	return body, nil
 }
 
-//CheckRegistry verify provided image belongs to harbor registry
+// CheckRegistry verify provided image belongs to harbor registry
 func (h *Harbor) checkRegistry(image string) bool {
 	reg := os.Getenv(registryDomain)
 	host := GetDomain(image)
@@ -221,7 +221,7 @@ func (h *Harbor) ScanImage(image string) (result map[string]interface{}, err err
 	return result, nil
 }
 
-//getProjectNameAndRepository fetch project and repo name
+// getProjectNameAndRepository fetch project and repo name
 func getProjectNameAndRepository(name string) (string, string) {
 	parts := strings.Split(name, "/")
 	if len(parts) >= 2 {
