@@ -148,7 +148,7 @@ var _ = Describe("Server File Scan", func() {
 
 				Context("unknown body attributes are present", func() {
 					Context("api server ignores unknown attributes", func() {
-						It("should receive violations and 200 OK resopnse", func() {
+						It("should receive violations and 200 OK response", func() {
 							bodyAttrs := make(map[string]string)
 							bodyAttrs["unknown_attribute"] = "someValue"
 
@@ -200,7 +200,7 @@ var _ = Describe("Server File Scan", func() {
 			iacFilePath, _ := filepath.Abs(filepath.Join(awsDbInsViolationRelPath, "main.tf"))
 
 			When("scan_rules is used", func() {
-				It("should receive violations and 200 OK resopnse", func() {
+				It("should receive violations and 200 OK response", func() {
 
 					bodyAttrs := make(map[string]string)
 					bodyAttrs["scan_rules"] = "AWS.RDS.DS.High.1041"
@@ -285,7 +285,7 @@ var _ = Describe("Server File Scan", func() {
 				When("multiple categories are sent but some of them are invalid", func() {
 					It("should receive a 400 bad request", func() {
 						bodyAttrs := make(map[string]string)
-						bodyAttrs["categories"] = " dATa pROtECtION, IDENTITY is Acess Management "
+						bodyAttrs["categories"] = " dATa pROtECtION, IDENTITY is Access Management "
 
 						serverUtils.MakeFileScanRequest(awsAmiIacFilePath, requestURL, bodyAttrs, http.StatusBadRequest)
 						Eventually(session.Err, serverUtils.ServerCommandTimeout).Should(gbytes.Say("category not supported"))
